Change "mctp instance id" to "pldm instance id"

Instance IDs are the ids given from the instanceID database
to the PLDM request and response messages.
Its not a MCTP thing but rather related to the PLDM messages.

Change-Id: I6eda652ec86cba691b8b2b848ca0c9227e4c05dc
Signed-off-by: Pavithra Barithaya <pavithrabarithaya07@gmail.com>
diff --git a/util/dbus.hpp b/util/dbus.hpp
index 29851ee..3dcca49 100644
--- a/util/dbus.hpp
+++ b/util/dbus.hpp
@@ -198,14 +198,14 @@
                           uint16_t stateSetId);
 
 /**
  * @brief Get MCTP instance ID associated with endpoint
  *
  * @param[out] mctpInstance - instance of MCTP
  * @param[in] Eid - MCTP enpoint ID
  *
  * @return True on success otherwise False
  */
-bool getMctpInstance(uint8_t& mctpInstance, uint8_t Eid);
+bool getPldmInstanceID(uint8_t& pldmInstanceID, uint8_t Eid);
 
 /**
  * @brief Determine if power fault was detected
@@ -198,14 +198,14 @@
 
 /**
- * @brief Get MCTP instance ID associated with endpoint
+ * @brief Get PLDM instance ID associated with endpoint
  *
@@ -198,14 +198,14 @@
  *
- * @param[out] mctpInstance - instance of MCTP
+ * @param[out] pldmInstanceID - PLDM instance id
  * @param[in] Eid - MCTP enpoint ID
  *